(()=>{var e={58556:()=>{}},t={};function r(n){if(t[n])return t[n].exports;var a=t[n]={exports:{}};return e[n](a,a.exports,r),a.exports}(()=>{"use strict";const e=Symbol("Comlink.proxy"),t=Symbol("Comlink.endpoint"),n=Symbol("Comlink.releaseProxy"),a=Symbol("Comlink.thrown"),s=e=>"object"==typeof e&&null!==e||"function"==typeof e,o=new Map([["proxy",{canHandle:t=>s(t)&&t[e],serialize(e){const{port1:t,port2:r}=new MessageChannel;return i(e,t),[r,[r]]},deserialize(e){return e.start(),function e(r,a=[],s=function(){}){let o=!1;const i=new Proxy(s,{get(t,s){if(u(o),s===n)return()=>y(r,{type:5,path:a.map(e=>e.toString())}).then(()=>{c(r),o=!0});if("then"===s){if(0===a.length)return{then:()=>i};const e=y(r,{type:0,path:a.map(e=>e.toString())}).then(m);return e.then.bind(e)}return e(r,[...a,s])},set(e,t,n){u(o);const[s,i]=f(n);return y(r,{type:1,path:[...a,t].map(e=>e.toString()),value:s},i).then(m)},apply(n,s,i){u(o);const c=a[a.length-1];if(c===t)return y(r,{type:4}).then(m);if("bind"===c)return e(r,a.slice(0,-1));const[p,f]=l(i);return y(r,{type:2,path:a.map(e=>e.toString()),argumentList:p},f).then(m)},construct(e,t){u(o);const[n,s]=l(t);return y(r,{type:3,path:a.map(e=>e.toString()),argumentList:n},s).then(m)}});return i}(e,[],r);var r}}],["throw",{canHandle:e=>s(e)&&a in e,serialize({value:e}){let t;return t=e instanceof Error?{isError:!0,value:{message:e.message,name:e.name,stack:e.stack}}:{isError:!1,value:e},[t,[]]},deserialize(e){if(e.isError)throw Object.assign(new Error(e.value.message),e.value);throw e.value}}]]);function i(t,r=self){r.addEventListener("message",(function n(s){if(!s||!s.data)return;const{id:o,type:u,path:l}=Object.assign({path:[]},s.data),y=(s.data.argumentList||[]).map(m);let g;try{const r=l.slice(0,-1).reduce((e,t)=>e[t],t),n=l.reduce((e,t)=>e[t],t);switch(u){case 0:g=n;break;case 1:r[l.slice(-1)[0]]=m(s.data.value),g=!0;break;case 2:g=n.apply(r,y);break;case 3:g=function(t){return Object.assign(t,{[e]:!0})}(new n(...y));break;case 4:{const{port1:e,port2:r}=new MessageChannel;i(t,r),g=function(e,t){return p.set(e,t),e}(e,[e])}break;case 5:g=void 0}}catch(d){g={value:d,[a]:0}}Promise.resolve(g).catch(e=>({value:e,[a]:0})).then(e=>{const[t,a]=f(e);r.postMessage(Object.assign(Object.assign({},t),{id:o}),a),5===u&&(r.removeEventListener("message",n),c(r))})})),r.start&&r.start()}function c(e){(function(e){return"MessagePort"===e.constructor.name})(e)&&e.close()}function u(e){if(e)throw new Error("Proxy has been released and is not useable")}function l(e){const t=e.map(f);return[t.map(e=>e[0]),(r=t.map(e=>e[1]),Array.prototype.concat.apply([],r))];var r}const p=new WeakMap;function f(e){for(const[t,r]of o)if(r.canHandle(e)){const[n,a]=r.serialize(e);return[{type:3,name:t,value:n},a]}return[{type:0,value:e},p.get(e)||[]]}function m(e){switch(e.type){case 3:return o.get(e.name).deserialize(e.value);case 0:return e.value}}function y(e,t,r){return new Promise(n=>{const a=new Array(4).fill(0).map(()=>Math.floor(Math.random()*Number.MAX_SAFE_INTEGER).toString(16)).join("-");e.addEventListener("message",(function t(r){r.data&&r.data.id&&r.data.id===a&&(e.removeEventListener("message",t),n(r.data))})),e.start&&e.start(),e.postMessage(Object.assign({id:a},t),r)})}r(58556);i({filterData:(e,t,r)=>(r=r.toUpperCase(),e.filter(e=>Object.entries(t).some(t=>{const[n,a]=t;return!(!a.filterable||!String(a.filterKey?e[n][a.filterKey]:e[n]).toUpperCase().includes(r))}))),sortData:(e,t,r,n)=>e.sort((e,a)=>{let s=1;"desc"===r&&(s=-1);let o=t.filterKey?e[n][t.filterKey]:e[n],i=t.filterKey?a[n][t.filterKey]:a[n];return"string"==typeof o&&(o=o.toUpperCase()),"string"==typeof i&&(i=i.toUpperCase()),o<i?-1*s:o>i?1*s:0})})})()})();
//# sourceMappingURL=chunk.4d88f915517f7966bc2b.js.map